@@ -34,6 +34,10 @@ import org.apache.tomcat.util.buf.UDecoder;
 import org.apache.tomcat.util.log.UserDataHelper;
 import org.apache.tomcat.util.res.StringManager;
 
+/**
+ *
+ * @author Costin Manolache
+ */
 public final class Parameters {
 
     private static final Log log = LogFactory.getLog(Parameters.class);
@@ -42,10 +46,12 @@ public final class Parameters {
 
     private static final UserDataHelper maxParamCountLog = new UserDataHelper(log);
 
-    private static final StringManager sm = StringManager.getManager("org.apache.tomcat.util.http");
+    private static final StringManager sm =
+        StringManager.getManager("org.apache.tomcat.util.http");
 
-    private final Map<String,ArrayList<String>> paramHashValues = new LinkedHashMap<>();
-    private boolean didQueryParameters = false;
+    private final Map<String,ArrayList<String>> paramHashValues =
+            new LinkedHashMap<>();
+    private boolean didQueryParameters=false;
 
     private MessageBytes queryMB;
 
@@ -59,8 +65,8 @@ public final class Parameters {
     private int parameterCount = 0;
 
     /**
-     * Set to the reason for the failure (the first failure if there is more than one) if there were failures during
-     * parameter parsing.
+     * Set to the reason for the failure (the first failure if there is more
+     * than one) if there were failures during parameter parsing.
      */
     private FailReason parseFailedReason = null;
 
@@ -68,8 +74,8 @@ public final class Parameters {
         // NO-OP
     }
 
-    public void setQuery(MessageBytes queryMB) {
-        this.queryMB = queryMB;
+    public void setQuery( MessageBytes queryMB ) {
+        this.queryMB=queryMB;
     }
 
     public void setLimit(int limit) {
@@ -85,8 +91,8 @@ public final class Parameters {
             charset = DEFAULT_BODY_CHARSET;
         }
         this.charset = charset;
-        if (log.isTraceEnabled()) {
-            log.trace("Set encoding to " + charset.name());
+        if(log.isDebugEnabled()) {
+            log.debug("Set encoding to " + charset.name());
         }
     }
 
@@ -96,8 +102,8 @@ public final class Parameters {
         }
         this.queryStringCharset = queryStringCharset;
 
-        if (log.isTraceEnabled()) {
-            log.trace("Set query string encoding to " + queryStringCharset.name());
+        if(log.isDebugEnabled()) {
+            log.debug("Set query string encoding to " + queryStringCharset.name());
         }
     }
 
@@ -153,11 +159,11 @@ public final class Parameters {
         return Collections.enumeration(paramHashValues.keySet());
     }
 
-    public String getParameter(String name) {
+    public String getParameter(String name ) {
         handleQueryParameters();
         ArrayList<String> values = paramHashValues.get(name);
         if (values != null) {
-            if (values.isEmpty()) {
+            if(values.size() == 0) {
                 return "";
             }
             return values.get(0);
@@ -165,10 +171,8 @@ public final class Parameters {
             return null;
         }
     }
-
     // -------------------- Processing --------------------
-    /**
-     * Process the query string into parameters
+    /** Process the query string into parameters
      */
     public void handleQueryParameters() {
         if (didQueryParameters) {
@@ -181,60 +185,63 @@ public final class Parameters {
             return;
         }
 
-        if (log.isTraceEnabled()) {
-            log.trace("Decoding query " + decodedQuery + " " + queryStringCharset.name());
+        if(log.isDebugEnabled()) {
+            log.debug("Decoding query " + decodedQuery + " " + queryStringCharset.name());
         }
 
         try {
             decodedQuery.duplicate(queryMB);
-        } catch (IOException ioe) {
+        } catch (IOException e) {
             // Can't happen, as decodedQuery can't overflow
-            log.error(sm.getString("parameters.copyFail"), ioe);
+            e.printStackTrace();
         }
         processParameters(decodedQuery, queryStringCharset);
     }
 
 
-    public void addParameter(String key, String value) throws IllegalStateException {
+    public void addParameter( String key, String value )
+            throws IllegalStateException {
 
-        if (key == null) {
+        if( key==null ) {
             return;
         }
 
-        if (limit > -1 && parameterCount >= limit) {
+        parameterCount ++;
+        if (limit > -1 && parameterCount > limit) {
             // Processing this parameter will push us over the limit. ISE is
             // what Request.parseParts() uses for requests that are too big
             setParseFailedReason(FailReason.TOO_MANY_PARAMETERS);
-            throw new IllegalStateException(sm.getString("parameters.maxCountFail", Integer.valueOf(limit)));
+            throw new IllegalStateException(sm.getString(
+                    "parameters.maxCountFail", Integer.valueOf(limit)));
         }
-        parameterCount++;
 
         paramHashValues.computeIfAbsent(key, k -> new ArrayList<>(1)).add(value);
     }
 
-    public void setURLDecoder(UDecoder u) {
-        urlDec = u;
+    public void setURLDecoder( UDecoder u ) {
+        urlDec=u;
     }
 
     // -------------------- Parameter parsing --------------------
     // we are called from a single thread - we can do it the hard way
     // if needed
-    private final ByteChunk tmpName = new ByteChunk();
-    private final ByteChunk tmpValue = new ByteChunk();
-    private final ByteChunk origName = new ByteChunk();
-    private final ByteChunk origValue = new ByteChunk();
+    private final ByteChunk tmpName=new ByteChunk();
+    private final ByteChunk tmpValue=new ByteChunk();
+    private final ByteChunk origName=new ByteChunk();
+    private final ByteChunk origValue=new ByteChunk();
     private static final Charset DEFAULT_BODY_CHARSET = StandardCharsets.ISO_8859_1;
     private static final Charset DEFAULT_URI_CHARSET = StandardCharsets.UTF_8;
 
 
-    public void processParameters(byte[] bytes, int start, int len) {
+    public void processParameters( byte bytes[], int start, int len ) {
         processParameters(bytes, start, len, charset);
     }
 
-    private void processParameters(byte[] bytes, int start, int len, Charset charset) {
+    private void processParameters(byte bytes[], int start, int len, Charset charset) {
 
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("parameters.bytes", new String(bytes, start, len, DEFAULT_BODY_CHARSET)));
+        if(log.isDebugEnabled()) {
+            log.debug(sm.getString("parameters.bytes",
+                    new String(bytes, start, len, DEFAULT_BODY_CHARSET)));
         }
 
         int decodeFailCount = 0;
@@ -242,7 +249,7 @@ public final class Parameters {
         int pos = start;
         int end = start + len;
 
-        while (pos < end) {
+        while(pos < end) {
             int nameStart = pos;
             int nameEnd = -1;
             int valueStart = -1;
@@ -254,7 +261,7 @@ public final class Parameters {
             boolean parameterComplete = false;
 
             do {
-                switch (bytes[pos]) {
+                switch(bytes[pos]) {
                     case '=':
                         if (parsingName) {
                             // Name finished. Value starts from next character
@@ -272,7 +279,7 @@ public final class Parameters {
                             nameEnd = pos;
                         } else {
                             // Value finished
-                            valueEnd = pos;
+                            valueEnd  = pos;
                         }
                         parameterComplete = true;
                         pos++;
@@ -285,10 +292,10 @@ public final class Parameters {
                         } else {
                             decodeValue = true;
                         }
-                        pos++;
+                        pos ++;
                         break;
                     default:
-                        pos++;
+                        pos ++;
                         break;
                 }
             } while (!parameterComplete && pos < end);
@@ -296,17 +303,18 @@ public final class Parameters {
             if (pos == end) {
                 if (nameEnd == -1) {
                     nameEnd = pos;
-                } else if (valueStart > -1 && valueEnd == -1) {
+                } else if (valueStart > -1 && valueEnd == -1){
                     valueEnd = pos;
                 }
             }
 
             if (log.isDebugEnabled() && valueStart == -1) {
-                log.debug(sm.getString("parameters.noequal", Integer.valueOf(nameStart), Integer.valueOf(nameEnd),
-                        new String(bytes, nameStart, nameEnd - nameStart, DEFAULT_BODY_CHARSET)));
+                log.debug(sm.getString("parameters.noequal",
+                        Integer.valueOf(nameStart), Integer.valueOf(nameEnd),
+                        new String(bytes, nameStart, nameEnd-nameStart, DEFAULT_BODY_CHARSET)));
             }
 
-            if (nameEnd <= nameStart) {
+            if (nameEnd <= nameStart ) {
                 if (valueStart == -1) {
                     // &&
                     if (log.isDebugEnabled()) {
@@ -320,11 +328,13 @@ public final class Parameters {
                 if (logMode != null) {
                     String extract;
                     if (valueEnd > nameStart) {
-                        extract = new String(bytes, nameStart, valueEnd - nameStart, DEFAULT_BODY_CHARSET);
+                        extract = new String(bytes, nameStart, valueEnd - nameStart,
+                                DEFAULT_BODY_CHARSET);
                     } else {
                         extract = "";
                     }
-                    String message = sm.getString("parameters.invalidChunk", Integer.valueOf(nameStart),
+                    String message = sm.getString("parameters.invalidChunk",
+                            Integer.valueOf(nameStart),
                             Integer.valueOf(valueEnd), extract);
                     switch (logMode) {
                         case INFO_THEN_DEBUG:
@@ -396,7 +406,8 @@ public final class Parameters {
                         String message = ise.getMessage();
                         switch (logMode) {
                             case INFO_THEN_DEBUG:
-                                message += sm.getString("parameters.maxCountFail.fallToDebug");
+                                message += sm.getString(
+                                        "parameters.maxCountFail.fallToDebug");
                                 //$FALL-THROUGH$
                             case INFO:
                                 log.info(message);
@@ -407,19 +418,19 @@ public final class Parameters {
                     }
                     break;
                 }
-            } catch (IOException ioe) {
+            } catch (IOException e) {
                 setParseFailedReason(FailReason.URL_DECODING);
                 decodeFailCount++;
                 if (decodeFailCount == 1 || log.isDebugEnabled()) {
                     if (log.isDebugEnabled()) {
-                        log.debug(
-                                sm.getString("parameters.decodeFail.debug", origName.toString(), origValue.toString()),
-                                ioe);
+                        log.debug(sm.getString("parameters.decodeFail.debug",
+                                origName.toString(), origValue.toString()), e);
                     } else if (log.isInfoEnabled()) {
                         UserDataHelper.Mode logMode = userDataLog.getNextMode();
                         if (logMode != null) {
-                            String message =
-                                    sm.getString("parameters.decodeFail.info", tmpName.toString(), tmpValue.toString());
+                            String message = sm.getString(
+                                    "parameters.decodeFail.info",
+                                    tmpName.toString(), tmpValue.toString());
                             switch (logMode) {
                                 case INFO_THEN_DEBUG:
                                     message += sm.getString("parameters.fallToDebug");
@@ -447,7 +458,9 @@ public final class Parameters {
         if (decodeFailCount > 1 && !log.isDebugEnabled()) {
             UserDataHelper.Mode logMode = userDataLog.getNextMode();
             if (logMode != null) {
-                String message = sm.getString("parameters.multipleDecodingFail", Integer.valueOf(decodeFailCount));
+                String message = sm.getString(
+                        "parameters.multipleDecodingFail",
+                        Integer.valueOf(decodeFailCount));
                 switch (logMode) {
                     case INFO_THEN_DEBUG:
                         message += sm.getString("parameters.fallToDebug");
@@ -462,23 +475,24 @@ public final class Parameters {
         }
     }
 
-    private void urlDecode(ByteChunk bc) throws IOException {
-        if (urlDec == null) {
-            urlDec = new UDecoder();
+    private void urlDecode(ByteChunk bc)
+        throws IOException {
+        if( urlDec==null ) {
+            urlDec=new UDecoder();
         }
         urlDec.convert(bc, true);
     }
 
     public void processParameters(MessageBytes data, Charset charset) {
-        if (data == null || data.isNull() || data.getLength() <= 0) {
+        if( data==null || data.isNull() || data.getLength() <= 0 ) {
             return;
         }
 
-        if (data.getType() != MessageBytes.T_BYTES) {
+        if( data.getType() != MessageBytes.T_BYTES ) {
             data.toBytes();
         }
-        ByteChunk bc = data.getByteChunk();
-        processParameters(bc.getBytes(), bc.getStart(), bc.getLength(), charset);
+        ByteChunk bc=data.getByteChunk();
+        processParameters(bc.getBytes(), bc.getOffset(), bc.getLength(), charset);
     }
 
     /**
@@ -487,7 +501,7 @@ public final class Parameters {
     @Override
     public String toString() {
         StringBuilder sb = new StringBuilder();
-        for (Map.Entry<String,ArrayList<String>> e : paramHashValues.entrySet()) {
+        for (Map.Entry<String, ArrayList<String>> e : paramHashValues.entrySet()) {
             sb.append(e.getKey()).append('=');
             StringUtils.join(e.getValue(), ',', sb);
             sb.append('\n');
@@ -503,12 +517,6 @@ public final class Parameters {
         IO_ERROR,
         NO_NAME,
         POST_TOO_LARGE,
-        /**
-         * Same as {@link #CLIENT_DISCONNECT}.
-         *
-         * @deprecated Unused. Will be removed in Tomcat 11.0.x onwards
-         */
-        @Deprecated
         REQUEST_BODY_INCOMPLETE,
         TOO_MANY_PARAMETERS,
         UNKNOWN,
